@@ -1,6 +1,6 @@
 /*
     common
-    copyright (c) 2002-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,9 +23,9 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif /* HAVE_CONFIG_H */
-#ifdef WIN32
-# include "config.w32.h"
-#endif /* WIN32 */
+#ifdef _MSC_VER
+# include "config.h.msc"
+#endif /* _MSC_VER */
 
 
 #include <stdio.h>
@@ -48,8 +48,12 @@
 
 #ifdef G_HAVE_GINT64
 typedef gint64 goffset;
+typedef gint64 glonglong;
+typedef guint64 gulonglong;
 #else /* not G_HAVE_GINT64 */
 typedef gint32 goffset;
+typedef gint32 glonglong;
+typedef guint32 gulonglong;
 #endif /* not G_HAVE_GINT64 */
 
 
@@ -68,8 +72,10 @@ typedef gint32 goffset;
 #define g_strstr(haystack,needle) g_strstr_len(haystack,g_strlen(haystack),needle)
 #ifdef G_OS_WIN32
 # define g_strfilecmp(s1,s2) g_strcasecmp(s1,s2)
+# define g_strfilencmp(s1,s2,n) g_strncasecmp(s1,s2,n)
 #else /* not G_OS_WIN32 */
 # define g_strfilecmp(s1,s2) g_strcmp(s1,s2)
+# define g_strfilencmp(s1,s2,n) g_strncmp(s1,s2,n)
 #endif /* not G_OS_WIN32 */
 
 #ifdef ENABLE_NLS
