@@ -21,9 +21,21 @@
 #ifdef HAVE_UTIME_H
 # include <utime.h>
 #endif /* HAVE_UTIME_H */
-#if defined TM_IN_SYS_TIME && defined HAVE_SYS_TIME
+#if defined (TM_IN_SYS_TIME) && defined (HAVE_SYS_TIME)
 # include <sys/time.h>
-#endif /* defined TM_IN_SYS_TIME && defined HAVE_SYS_TIME */
+#endif /* defined (TM_IN_SYS_TIME) && defined (HAVE_SYS_TIME) */
+
+
+struct _FileIO
+{
+#ifdef G_OS_WIN32
+  HANDLE hFile;
+#else /* not G_OS_WIN32 */
+  int fd;
+  gchar *file;
+  guint share;
+#endif /* not G_OS_WIN32 */
+};
 
 
 /******************************************************************************
@@ -83,7 +95,11 @@ fileio_test (const gchar *file,
       SHFILEINFOA rcInfo;
       WIN32_FIND_DATAA rcFind;
 
+#  if GLIB_CHECK_VERSION(2,8,0)
+      lpszFile = g_win32_locale_filename_from_utf8 (file);
+#  else /* not GLIB_CHECK_VERSION(2,8,0) */
       lpszFile = g_locale_from_utf8 (file, -1, NULL, NULL, NULL);
+#  endif /* not GLIB_CHECK_VERSION(2,8,0) */
       if (!lpszFile)
         return FALSE;
       if ((test & FILEIO_TEST_IS_EXECUTABLE) && SHGetFileInfoA (lpszFile, 0,
@@ -165,17 +181,19 @@ fileio_test (const gchar *file,
 }
 
 
-/*  ja:ファイルのフルパスを取得する
+/*  ja:ファイルの絶対パスを取得する
     file,ファイル名
+    path,パス名
      RET,フルパス                                                           */
 gchar *
-fileio_get_full_path (const gchar *file)
+fileio_get_absolute_path (const gchar *file,
+                          const gchar *path)
 {
 #ifdef G_OS_WIN32
   int i = 0, j, s;
   DWORD dwSize;             /* フルパスの長さ */
   HANDLE hFind;             /* 検索ハンドル */
-# if !GLIB_CHECK_VERSION(2,6,0)
+# if ! GLIB_CHECK_VERSION(2,6,0)
   LPTSTR p;
   TCHAR szFile[MAX_PATH];   /* フルパス */
   TCHAR lpszLongName[MAX_PATH];
@@ -271,7 +289,11 @@ fileio_get_full_path (const gchar *file)
       CHAR szFile[MAX_PATH];   /* フルパス */
       CHAR szLongName[MAX_PATH];
 
+#  if GLIB_CHECK_VERSION(2,8,0)
+      lpszFile = g_win32_locale_filename_from_utf8 (file);
+#  else /* not GLIB_CHECK_VERSION(2,8,0) */
       lpszFile = g_locale_from_utf8 (file, -1, NULL, NULL, NULL);
+#  endif /* not GLIB_CHECK_VERSION(2,8,0) */
       dwSize = GetFullPathNameA (lpszFile, MAX_PATH, szFile, &p);
       g_free (lpszFile);
       if (dwSize == 0 || dwSize >= MAX_PATH)
@@ -439,30 +461,40 @@ fileio_get_full_path (const gchar *file)
 #  endif /* not UNICODE */
 # endif /* not GLIB_CHECK_VERSION(2,6,0) */
 #else /* not G_OS_WIN32 */
-  gchar *path;
+  gchar *absolate;
   gint i, leng;
 
   if (!file)
     return NULL;
   if (file[0] != G_DIR_SEPARATOR)
     {
-      gchar *dir;
+      if (path && g_path_is_absolute (path))
+        {
+          leng = g_strlen (path);
+          absolate = leng > 0 && path[leng - 1] == G_DIR_SEPARATOR
+                        ? g_strconcat (path, file, NULL)
+                        : g_strconcat (path, G_DIR_SEPARATOR_S, file, NULL);
+        }
+      else
+        {
+          gchar *dir;
 
-      dir = g_get_current_dir ();
-      path = g_strconcat (dir, G_DIR_SEPARATOR_S, file, NULL);
-      g_free (dir);
+          dir = g_get_current_dir ();
+          absolate = g_strconcat (dir, G_DIR_SEPARATOR_S, file, NULL);
+          g_free (dir);
+        }
     }
   else
     {
-      path = g_strdup (file);
+      absolate = g_strdup (file);
     }
-  leng = g_strlen (path);
+  leng = g_strlen (absolate);
   i = 0;
   while (i < leng)
-    if (path[i] == G_DIR_SEPARATOR && path[i + 1] == G_DIR_SEPARATOR)
+    if (absolate[i] == G_DIR_SEPARATOR && absolate[i + 1] == G_DIR_SEPARATOR)
       {
         leng--;
-        g_memmove (path + i + 1, path + i + 2, leng - i);
+        g_memmove (absolate + i + 1, absolate + i + 2, leng - i);
       }
     else
       {
@@ -470,11 +502,11 @@ fileio_get_full_path (const gchar *file)
       }
   i = 0;
   while (i < leng)
-    if (path[i] == G_DIR_SEPARATOR && path[i + 1] == '.'
-                                            && path[i + 2] == G_DIR_SEPARATOR)
+    if (absolate[i] == G_DIR_SEPARATOR && absolate[i + 1] == '.'
+                                        && absolate[i + 2] == G_DIR_SEPARATOR)
       {
         leng -= 2;
-        g_memmove (path + i + 1, path + i + 3, leng - i);
+        g_memmove (absolate + i + 1, absolate + i + 3, leng - i);
       }
     else
       {
@@ -482,19 +514,19 @@ fileio_get_full_path (const gchar *file)
       }
   i = 0;
   while (i < leng)
-    if (path[i] == G_DIR_SEPARATOR && path[i + 1] == '.'
-                    && path[i + 2] == '.' && path[i + 3] == G_DIR_SEPARATOR)
+    if (absolate[i] == G_DIR_SEPARATOR && absolate[i + 1] == '.'
+            && absolate[i + 2] == '.' && absolate[i + 3] == G_DIR_SEPARATOR)
       {
         gint j;
 
         leng -= 3;
-        g_memmove (path + i + 1, path + i + 4, leng - i);
+        g_memmove (absolate + i + 1, absolate + i + 4, leng - i);
         for (j = i - 1; j >= 0; j--)
-          if (path[j] == G_DIR_SEPARATOR)
+          if (absolate[j] == G_DIR_SEPARATOR)
             break;
         if (j >= 0)
           {
-            g_memmove (path + j + 1, path + i + 1, leng - i);
+            g_memmove (absolate + j + 1, absolate + i + 1, leng - i);
             leng -= i - j;
             i = j;
           }
@@ -503,7 +535,7 @@ fileio_get_full_path (const gchar *file)
       {
         i++;
       }
-  return path;
+  return absolate;
 #endif /* not G_OS_WIN32 */
 }
 
@@ -604,7 +636,7 @@ fileio_open (const gchar *file,
   FileIO *fio;
 #ifdef G_OS_WIN32
   HANDLE hFile;
-# if !GLIB_CHECK_VERSION(2,6,0)
+# if ! GLIB_CHECK_VERSION(2,6,0)
 #  ifdef UNICODE
   gchar *utf8file, *utf16file;
   LPTSTR lpszFile;
@@ -627,7 +659,11 @@ fileio_open (const gchar *file,
     {
       LPSTR lpszFile;
 
+#  if GLIB_CHECK_VERSION(2,8,0)
+      lpszFile = g_win32_locale_filename_from_utf8 (file);
+#  else /* not GLIB_CHECK_VERSION(2,8,0) */
       lpszFile = g_locale_from_utf8 (file, -1, NULL, NULL, NULL);
+#  endif /* not GLIB_CHECK_VERSION(2,8,0) */
       hFile = CreateFileA (lpszFile, access, share, NULL, mode,
                                                 FILE_ATTRIBUTE_NORMAL, NULL);
       g_free (lpszFile);
@@ -982,7 +1018,7 @@ fileio_gettime (const gchar *file,
 {
 #ifdef G_OS_WIN32
   HANDLE hFind;
-# if !GLIB_CHECK_VERSION(2,6,0)
+# if ! GLIB_CHECK_VERSION(2,6,0)
   WIN32_FIND_DATA rcFind;
 #  ifdef UNICODE
   gchar *utf8file;
@@ -1019,7 +1055,11 @@ fileio_gettime (const gchar *file,
       LPSTR lpszFile;
       WIN32_FIND_DATAA rcFind;
 
+#  if GLIB_CHECK_VERSION(2,8,0)
+      lpszFile = g_win32_locale_filename_from_utf8 (file);
+#  else /* not GLIB_CHECK_VERSION(2,8,0) */
       lpszFile = g_locale_from_utf8 (file, -1, NULL, NULL, NULL);
+#  endif /* not GLIB_CHECK_VERSION(2,8,0) */
       if (!lpszFile)
         return FALSE;
       hFind = FindFirstFileA (lpszFile, &rcFind);
@@ -1079,10 +1119,10 @@ fileio_settime (const gchar *file,
 {
 #ifdef G_OS_WIN32
   HANDLE hFile;
-# if defined UNICODE && !GLIB_CHECK_VERSION(2,6,0)
+# if defined (UNICODE) && ! GLIB_CHECK_VERSION(2,6,0)
   gchar *utf8file;
   LPTSTR lpszFile;
-# endif /* UNICODE and not GLIB_CHECK_VERSION(2,6,0) */
+# endif /* defined (UNICODE) && ! GLIB_CHECK_VERSION(2,6,0) */
 #else /* not G_OS_WIN32 */
   struct stat sbuf;
   struct utimbuf ubuf;
@@ -1108,7 +1148,11 @@ fileio_settime (const gchar *file,
     {
       LPSTR lpszFile;
 
+#  if GLIB_CHECK_VERSION(2,8,0)
+      lpszFile = g_win32_locale_filename_from_utf8 (file);
+#  else /* not GLIB_CHECK_VERSION(2,8,0) */
       lpszFile = g_locale_from_utf8 (file, -1, NULL, NULL, NULL);
+#  endif /* not GLIB_CHECK_VERSION(2,8,0) */
       if (!lpszFile)
         return FALSE;
       hFile = CreateFileA (lpszFile, GENERIC_WRITE,
@@ -1201,7 +1245,7 @@ fileio_extract_icon (const gchar *file)
   GdkPixbuf *pixbuf = NULL;
   HICON hIcon = NULL;
   ICONINFO ii;
-# if !GLIB_CHECK_VERSION(2,6,0)
+# if ! GLIB_CHECK_VERSION(2,6,0)
   SHFILEINFO shfi;
 #  ifdef UNICODE
   gchar *utf8file;
@@ -1226,7 +1270,11 @@ fileio_extract_icon (const gchar *file)
       SHFILEINFOA shfi;
       LPSTR lpszFile;
 
+#  if GLIB_CHECK_VERSION(2,8,0)
+      lpszFile = g_win32_locale_filename_from_utf8 (file);
+#  else /* not GLIB_CHECK_VERSION(2,8,0) */
       lpszFile = g_locale_from_utf8 (file, -1, NULL, NULL, NULL);
+#  endif /* not GLIB_CHECK_VERSION(2,8,0) */
       if ((BOOL)SHGetFileInfoA (lpszFile, 0, &shfi, sizeof (SHFILEINFOW),
                     SHGFI_ICON | SHGFI_SMALLICON | SHGFI_USEFILEATTRIBUTES))
         hIcon = shfi.hIcon;
