@@ -88,17 +88,25 @@ command_open (GtkWidget *widget,
   TCHAR szFile[MAX_PATH];
 # ifdef UNICODE
   gchar *utf8file;
-  gunichar2 *utf16file = NULL;
 
   utf8file = g_filename_to_utf8 (open_path, -1, NULL, NULL, NULL);
   if (utf8file)
     {
-      utf16file = g_utf8_to_utf16 (utf8file, -1, NULL, NULL, NULL);
+      lpszPath = g_utf8_to_utf16 (utf8file, -1, NULL, NULL, NULL);
       g_free (utf8file);
     }
-  lpszPath = utf16file;
+  else
+    {
+      lpszPath = NULL;
+    }
 # else /* not UNICODE */
+#  if GTK_CHECK_VERSION(2,8,0)
+  lpszPath = g_win32_locale_filename_from_utf8 (open_path);
+#  elif GTK_CHECK_VERSION(2,6,0)
+  lpszPath = g_locale_from_utf8 (open_path, -1, NULL, NULL, NULL);
+#  else /* not GTK_CHECK_VERSION(2,6,0) */
   lpszPath = g_strdup (open_path);
+#  endif /* not GTK_CHECK_VERSION(2,6,0) */
 # endif /* not UNICODE */
   /* ja:フィルタの設定 */
   for (i = 0; i < ftnum; i++)
@@ -135,16 +143,20 @@ command_open (GtkWidget *widget,
   if (GetOpenFileName (&ofn))
 # ifdef UNICODE
     {
-      utf16file = g_utf16_to_utf8 (szFile, -1, NULL, NULL, NULL);
-      if (utf16file)
+      utf8file = g_utf16_to_utf8 (szFile, -1, NULL, NULL, NULL);
+      if (utf8file)
         {
-          file = g_filename_from_utf8 (utf16file, -1, NULL, NULL, NULL);
-          g_free (utf16file);
+          file = g_filename_from_utf8 (utf8file, -1, NULL, NULL, NULL);
+          g_free (utf8file);
         }
       findex = ofn.nFilterIndex - 1;
     }
 # else /* not UNICODE */
+#  if GTK_CHECK_VERSION(2,6,0)
+    file = g_locale_to_utf8 (szFile, -1, NULL, NULL, NULL);
+#  else /* not GTK_CHECK_VERSION(2,6,0) */
     file = g_strdup (szFile);
+#  endif /* not GTK_CHECK_VERSION(2,6,0) */
 # endif /* not UNICODE */
   g_free (lpszPath);
   g_free (lpszFilter);
@@ -271,17 +283,25 @@ command_saveas (GtkWidget *widget,
   TCHAR szFile[MAX_PATH];
 # ifdef UNICODE
   gchar *utf8file;
-  gunichar2 *utf16file = NULL;
 
   utf8file = g_filename_to_utf8 (save_path, -1, NULL, NULL, NULL);
   if (utf8file)
     {
-      utf16file = g_utf8_to_utf16 (utf8file, -1, NULL, NULL, NULL);
+      lpszPath = g_utf8_to_utf16 (utf8file, -1, NULL, NULL, NULL);
       g_free (utf8file);
     }
-  lpszPath = utf16file;
+  else
+    {
+      lpszPath = NULL;
+    }
 # else /* not UNICODE */
+#  if GTK_CHECK_VERSION(2,8,0)
+  lpszPath = g_win32_locale_filename_from_utf8 (save_path);
+#  elif GTK_CHECK_VERSION(2,6,0)
+  lpszPath = g_locale_from_utf8 (save_path, -1, NULL, NULL, NULL);
+#  else /* not GTK_CHECK_VERSION(2,6,0) */
   lpszPath = g_strdup (save_path);
+#  endif /* not GTK_CHECK_VERSION(2,6,0) */
 # endif /* not UNICODE */
   /* ja:フィルタの設定 */
   for (i = 0; i < ftnum; i++)
@@ -327,7 +347,11 @@ command_saveas (GtkWidget *widget,
       findex = ofn.nFilterIndex - 1;
     }
 # else /* not UNICODE */
+#  if GTK_CHECK_VERSION(2,6,0)
+    file = g_locale_to_utf8 (szFile, -1, NULL, NULL, NULL);
+#  else /* not GTK_CHECK_VERSION(2,6,0) */
     file = g_strdup (szFile);
+#  endif /* not GTK_CHECK_VERSION(2,6,0) */
 # endif /* not UNICODE */
   g_free (lpszPath);
   g_free (lpszFilter);
