@@ -168,4 +168,4 @@ command_version (GtkWidget *widget,
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __COMMAND_H__ */
