@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-typedef struct FindString_Tag
+typedef struct _FindString
 {
   gboolean arrow;
   gboolean ignorecase;
@@ -80,4 +80,4 @@ find_dialog (FindString *fd);
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __FIND_H__ */
