@@ -73,7 +73,7 @@ ftype_copy (FileType *ft_dst,
 * ja:ファイルタイプダイアログ関数群                                           *
 *                                                                             *
 ******************************************************************************/
-typedef struct FileTypeDialog_Tag
+typedef struct _FileTypeDialog
 {
   gboolean edited;
   gint row;
