@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-typedef struct JumpDialog_Tag
+typedef struct _JumpDialog
 {
   gint cursor,max;
 } JumpDialog;
@@ -63,4 +63,4 @@ gboolean jump_dialog(JumpDialog *jmp);
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __JUMP_H__ */
