@@ -86,7 +86,7 @@ print_out (TmaidWindow *tmaid,
     {
       /* ja:選択範囲なし、すべて印刷 */
       start.x = start.y = 0;
-      end.x = edit_get_width (tmaid,tmaid->max - 1);
+      end.x = edit_get_width (tmaid, tmaid->max - 1);
       end.y = tmaid->max - 1;
     }
   else if (tmaid->select.y < tmaid->cursor.y
@@ -178,7 +178,7 @@ print_out (TmaidWindow *tmaid,
   dialog = abort_dialog (_("Printing"));
   gtk_grab_add (dialog);
 #if defined G_OS_UNIX
-  for (i = 0; i < prncfg->mode ? 1 : prncfg->copies; i++)
+  for (i = 0; i < prncfg->mode ? prncfg->copies : 1; i++)
 #elif defined G_OS_WIN32
   for (i = 0; i < prncfg->copies; i++)
 #endif
@@ -313,7 +313,7 @@ print_out (TmaidWindow *tmaid,
                                     +c[x * channels + y * rowstride + 1] * 150
                                     +c[x * channels + y * rowstride + 2] * 29)
                                                                         / 256);
-                    fputc('\n',fp);
+                    fputc ('\n', fp);
                   }
                 break;
               default:
@@ -324,7 +324,7 @@ print_out (TmaidWindow *tmaid,
                     fputc ('\n', fp);
                   }
             }
-          fputs("grestore\nshowpage\n",fp);
+          fputs ("grestore\nshowpage\n", fp);
 #endif /* not G_OS_WIN32 */
           if (!userbreak)
             goto loop;
@@ -375,11 +375,14 @@ print_out (TmaidWindow *tmaid,
 ******************************************************************************/
 static gboolean print_clicked_ok;
 static GtkWidget *dialog, *button1, *label1, *spin0;
+#if defined G_OS_UNIX || defined G_OS_WIN32
+static GtkWidget *label2, *spin1;
+#endif /* G_OS_UNIX or G_OS_WIN32 */
 #ifndef G_OS_WIN32
 static GtkWidget *button0, *check, *entry1, *label3, *label4;
 static GtkWidget *spin2, *spin3, *spin4, *spin5, *spin6, *spin7;
 # ifdef G_OS_UNIX
-static GtkWidget *entry0, *label2, *radio0, *spin1;
+static GtkWidget *entry0, *radio0;
 # endif /* G_OS_UNIX */
 static struct
 {
@@ -396,23 +399,27 @@ print_dialog_ok_sensitive (GtkWidget   *widget,
                            PrintConfig *prncfg)
 {
   gint column, row;
+#if defined G_OS_UNIX || defined G_OS_WIN32
+  gint copies;
+#endif /* G_OS_UNIX or G_OS_WIN32 */
 #ifndef G_OS_WIN32
   gint width, height, left, top, right, bottom;
 # ifdef G_OS_UNIX
   gboolean mode;
-  gint copies;
 # endif /* G_OS_UNIX */
 #endif /* not G_OS_WIN32 */
 
   column = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin0));
+#if defined G_OS_UNIX || defined G_OS_WIN32
+  copies = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin1));
+#endif /* G_OS_UNIX or G_OS_WIN32 */
 #ifdef G_OS_WIN32
   row = column * prncfg->font_width * prncfg->height
                                     / (prncfg->width * prncfg->font_height);
-  gtk_widget_set_sensitive (button1, column >= 1 && row >= 1);
+  gtk_widget_set_sensitive (button1, column >= 1 && row >= 1 && copies >= 1);
 #else /* not G_OS_WIN32 */
 # ifdef G_OS_UNIX
   mode = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio0));
-  copies = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin1));
 # endif /* G_OS_UNIX */
   width = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin2));
   height = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin3));
@@ -540,10 +547,8 @@ print_dialog_toggled (GtkWidget   *widget,
   gtk_widget_set_sensitive (entry0, result);
   gtk_widget_set_sensitive (entry1, !result);
   gtk_widget_set_sensitive (button0, !result);
-# ifdef G_OS_UNIX
-  gtk_widget_set_sensitive (label2, !result);
-  gtk_widget_set_sensitive (spin1, !result);
-# endif /* not G_OS_UNIX */
+  gtk_widget_set_sensitive (label2, result);
+  gtk_widget_set_sensitive (spin1, result);
   print_dialog_ok_sensitive (widget, prncfg);
 }
 #endif /* G_OS_UNIX */
@@ -554,6 +559,9 @@ static void
 print_dialog_clicked_ok (GtkWidget   *widget,
                          PrintConfig *prncfg)
 {
+#if defined G_OS_UNIX || defined G_OS_WIN32
+  prncfg->copies = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin1));
+#endif /* G_OS_UNIX or G_OS_WIN32 */
 #ifndef G_OS_WIN32
 # ifdef G_OS_UNIX
   prncfg->mode = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio0));
@@ -561,8 +569,6 @@ print_dialog_clicked_ok (GtkWidget   *widget,
     {
       g_free (prncfg->printer);
       prncfg->printer = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry0)));
-      prncfg->copies
-                = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin1));
     }
   else
     {
@@ -699,8 +705,10 @@ static void
 print_dialog_activate (GtkWidget   *widget,
                        PrintConfig *prncfg)
 {
+
 #ifdef G_OS_WIN32
-  if (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin0)) >= 1)
+  if (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin0)) >= 1
+            && gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin1)) >= 1)
     print_dialog_clicked_ok (widget, prncfg);
 #else /* not G_OS_WIN32 */
   gint left, top, right, bottom;
@@ -724,9 +732,9 @@ print_dialog_activate (GtkWidget   *widget,
 # endif /* not G_OS_UNIX */
         && gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin0)) >= 1
         && left >= 0 && top >= 0 && right >= 0 && bottom >= 0
-        && gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin1))
-                                                                > left + right
         && gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin2))
+                                                                > left + right
+        && gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin3))
                                                                 > top + bottom)
     print_dialog_clicked_ok (widget, prncfg);
 #endif /* not G_OS_WIN32 */
@@ -778,8 +786,8 @@ print_dialog (PrintConfig *prncfg)
   prncfg->pd.nCopies = prncfg->copies;
   if (!PrintDlg (&prncfg->pd))
     return FALSE;
-  prncfg->width = GetDeviceCaps (prncfg->pd.hDC,HORZRES);
-  prncfg->height = GetDeviceCaps (prncfg->pd.hDC,VERTRES) * 24 / 25;
+  prncfg->width = GetDeviceCaps (prncfg->pd.hDC, HORZRES);
+  prncfg->height = GetDeviceCaps (prncfg->pd.hDC, VERTRES) * 24 / 25;
   if (prncfg->select)
     prncfg->select = (prncfg->pd.Flags & PD_SELECTION) != 0;
   prncfg->copies = prncfg->pd.nCopies;
@@ -813,6 +821,19 @@ print_dialog (PrintConfig *prncfg)
   label0 = gtk_label_new_with_mnemonic (_("_Columns"));
   label1 = gtk_label_new ("");
   gtk_label_set_mnemonic_widget (GTK_LABEL (label0), spin0);
+#if defined G_OS_UNIX || defined G_OS_WIN32
+  /* ja:スピンボタン */
+  spin1 = gtk_spin_button_new (GTK_ADJUSTMENT (gtk_adjustment_new
+                                (prncfg->copies, 1, G_MAXINT, 1, 5, 0)), 0, 0);
+  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spin1), TRUE);
+  g_signal_connect (G_OBJECT(spin1), "activate",
+                                G_CALLBACK (print_dialog_activate), prncfg);
+  g_signal_connect (G_OBJECT (spin1), "changed",
+                            G_CALLBACK (print_dialog_changed_spin), prncfg);
+  /* ja:ラベル */
+  label2 = gtk_label_new_with_mnemonic (_("C_opies"));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label2), spin1);
+#endif /* G_OS_UNIX or G_OS_WIN32 */
 #ifndef G_OS_WIN32
   /* ja:ボタン */
   button0 = gtk_button_new_with_label (_("Browse..."));
@@ -898,17 +919,6 @@ print_dialog (PrintConfig *prncfg)
                             G_CALLBACK (print_dialog_clicked_ok), prncfg);
   g_signal_connect (G_OBJECT (entry0), "changed",
                             G_CALLBACK (print_dialog_ok_sensitive), prncfg);
-  /* ja:スピンボタン */
-  spin1 = gtk_spin_button_new (GTK_ADJUSTMENT (gtk_adjustment_new
-                                (prncfg->copies, 1, G_MAXINT, 1, 5, 0)), 0, 0);
-  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spin1), TRUE);
-  g_signal_connect (G_OBJECT(spin1), "activate",
-                                G_CALLBACK (print_dialog_activate), prncfg);
-  g_signal_connect (G_OBJECT (spin1), "changed",
-                            G_CALLBACK (print_dialog_changed_spin), prncfg);
-  /* ja:ラベル */
-  label2 = gtk_label_new_with_mnemonic (_("C_opies"));
-  gtk_label_set_mnemonic_widget (GTK_LABEL (label2), spin1);
   /* ja:ラジオボタン */
   radio0 = gtk_radio_button_new_with_mnemonic (NULL, _("_Printer"));
   radio1 = gtk_radio_button_new_with_mnemonic_from_widget
@@ -1030,14 +1040,16 @@ print_dialog (PrintConfig *prncfg)
   gtk_box_pack_start (GTK_BOX (hbox1), button0, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox0), hbox1, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox0, FALSE, FALSE, 0);
+#endif /* not G_OS_WIN32 */
 
-# ifdef G_OS_UNIX
+#if defined G_OS_UNIX || defined G_OS_WIN32
   hbox0 = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox0), label2, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox0), spin1, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox0, FALSE, FALSE, 0);
-# endif /* G_OS_UNIX */
+#endif /* G_OS_UNIX or G_OS_WIN32 */
 
+#ifndef G_OS_WIN32
   gtk_box_pack_start (GTK_BOX (vbox), frame0, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), frame1, FALSE, FALSE, 0);
 #endif /* not G_OS_WIN32 */
