@@ -139,7 +139,7 @@ property_change (TmaidWindow *tmaid,
 * ja:プロパティダイアログ関数群                                               *
 *                                                                             *
 ******************************************************************************/
-typedef struct PropertyDialog_Tag
+typedef struct _PropertyDialog
 {
   gboolean clicked_ok, color_list[12];
   gchar *charset_list;
