@@ -828,7 +828,9 @@ signal_button_press (GtkWidget      *widget,
                                             "/copy"), tmaid->select.x >= 0);
                 gtk_widget_set_sensitive (misc_find_menu (popup_entries,
                                             "/delete"), tmaid->select.x >= 0);
-                gtk_menu_popup (GTK_MENU (misc_find_menu (popup_entries, "/")),
+                menu_shell = misc_find_menu (popup_entries, "/");
+                gtk_widget_show_all (menu_shell);
+                gtk_menu_popup (GTK_MENU (menu_shell),
                         NULL, NULL, NULL, NULL, event->button, event->time);
               }
           }
