@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -167,4 +167,4 @@ signal_scroll (GtkWidget      *widget,
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __SIGFILE_H__ */
