@@ -172,15 +172,35 @@ main (int   argc,
   bindtextdomain (PACKAGE, LOCALEDIR);
 #else /* not LOCALEDIR */
   {
-    gchar *dirname, *path, *locale;
+      gchar *dirname, *path, *locale;
+# if defined (G_OS_WIN32) && GLIB_CHECK_VERSION(2,6,0)
+      gchar *temp;
+# endif /* defined (G_OS_WIN32) && GLIB_CHECK_VERSION(2,6,0) */
 
-    path = fileio_get_full_path (argv[0]);
-    dirname = g_path_get_dirname (path);
-    g_free (path);
-    locale = g_strconcat (dirname, G_DIR_SEPARATOR_S, "locale", NULL);
-    g_free (dirname);
-    bindtextdomain (PACKAGE, locale);
-    g_free (locale);
+      path = fileio_get_full_path (argv[0]);
+      dirname = g_path_get_dirname (path);
+      g_free (path);
+      locale = g_strconcat (dirname, G_DIR_SEPARATOR_S, "locale", NULL);
+      g_free (dirname);
+# ifdef G_OS_WIN32
+      if (!fileio_isfile (locale))
+        {
+          g_free (locale);
+          locale = g_win32_get_package_installation_subdirectory
+                            (NULL, argv[0], "lib" G_DIR_SEPARATOR_S "locale");
+        }
+# endif /* G_OS_WIN32 */
+# if defined (G_OS_WIN32) && GLIB_CHECK_VERSION(2,6,0)
+#  if GLIB_CHECK_VERSION(2,8,0)
+      temp = g_win32_locale_filename_from_utf8 (locale);
+#  else /* not GLIB_CHECK_VERSION(2,8,0) */
+      temp = g_locale_from_utf8 (locale, -1, NULL, NULL, NULL);
+#  endif /* not GLIB_CHECK_VERSION(2,8,0) */
+      g_free (locale);
+      locale = temp;
+# endif /* defined (G_OS_WIN32) && GLIB_CHECK_VERSION(2,6,0) */
+      bindtextdomain (PACKAGE, locale);
+      g_free (locale);
   }
 #endif /* not LOCALEDIR */
   bind_textdomain_codeset (PACKAGE, "UTF-8");
