@@ -35,7 +35,7 @@ extern "C" {
 #define MENUFILE 12
 
 
-typedef struct FileType_Tag
+typedef struct _FileType
 {
   gint ft_id;               /* ja:ファイルタイプのID(-1:無所属) */
   gint crlf;                /* ja:0:CR+LF,1:CR,2:LF,3:自動 */
@@ -64,22 +64,22 @@ typedef struct FileType_Tag
   gchar *text, *ext;        /* ja:名前,拡張子 */
   GdkColor color[12];       /* ja:色 */
 } FileType;
-typedef struct TmaidHistory_Tag
+typedef struct _TmaidHistory
 {
   gboolean caret;
   gchar *text;
   gint length;              /* ja:文字数 */
   GdkPoint cursor, select;
-  struct TmaidHistory_Tag *next;
+  struct _TmaidHistory *next;
 } TmaidHistory;
-typedef struct LineBuffer_Tag
+typedef struct _LineBuffer
 {
   gboolean margin;          /* ja:TRUE:右マージン,FALSE:通常の改行 */
   gchar *text;
   gint length;              /* ja:文字数 */
-  struct LineBuffer_Tag *prev, *next;
+  struct _LineBuffer *prev, *next;
 } LineBuffer;
-typedef struct TmaidWindow_Tag
+typedef struct _TmaidWindow
 {
   gint font_width;          /* ja:フォントの横幅 */
   gint font_height;         /* ja:フォントの高さ */
@@ -151,7 +151,7 @@ extern MiscCreateMenuEntry popup_entries[];
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __TMAID_H__ */
 /*
 ja:表示色
  0,文字
